==> drosgenome1.db_2.2.11.tar.gz: drosgenome1.db/man/drosgenome1_dbconn.Rd <==
\name{drosgenome1_dbconn}

\alias{drosgenome1_dbconn}
\alias{drosgenome1_dbfile}
\alias{drosgenome1_dbschema}
\alias{drosgenome1_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  drosgenome1_dbconn()
  drosgenome1_dbfile()
  drosgenome1_dbschema(file="", show.indices=FALSE)
  drosgenome1_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{drosgenome1_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{drosgenome1_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{drosgenome1_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{drosgenome1_dbschema} prints the schema definition of the
  package annotation DB.

  \code{drosgenome1_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{drosgenome1_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{drosgenome1_dbfile}: a character string with the path to the
  package annotation DB.

  \code{drosgenome1_dbschema}: none (invisible \code{NULL}).

  \code{drosgenome1_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(drosgenome1_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by drosgenome1_dbconn() was created with:
  dbConnect(SQLite(), dbname=drosgenome1_dbfile(), cache_size=64000, synchronous=0)

  drosgenome1_dbschema()

  drosgenome1_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> drosgenome1.db_2.4.1.tar.gz: drosgenome1.db/man/drosgenome1_dbconn.Rd <==

\name{drosgenome1_dbconn}

\alias{drosgenome1_dbconn}
\alias{drosgenome1_dbfile}
\alias{drosgenome1_dbschema}
\alias{drosgenome1_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  drosgenome1_dbconn()
  drosgenome1_dbfile()
  drosgenome1_dbschema(file="", show.indices=FALSE)
  drosgenome1_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{drosgenome1_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{drosgenome1_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{drosgenome1_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{drosgenome1_dbschema} prints the schema definition of the
  package annotation DB.

  \code{drosgenome1_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{drosgenome1_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{drosgenome1_dbfile}: a character string with the path to the
  package annotation DB.

  \code{drosgenome1_dbschema}: none (invisible \code{NULL}).

  \code{drosgenome1_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(drosgenome1_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by drosgenome1_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=drosgenome1_dbfile(), cache_size=64000,
  synchronous=0)

  drosgenome1_dbschema()

  drosgenome1_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
